Module: PasskeysRails::Test

Defined in:
lib/passkeys_rails/test/integration_helpers.rb,
lib/passkeys-rails.rb

Overview

PasskeysRails::Test::IntegrationHelpers is a helper module for facilitating authentication on Rails integration tests to bypass the required steps for signin in or signin out a record.

Examples

class PostsTest < ActionDispatch::IntegrationTest include PasskeysRails::Test::IntegrationHelpers

test 'authenticated users can see posts' do
 get '/posts', headers: logged_in_headers('username-1')
 assert_response :success
end

end

Defined Under Namespace

Modules: IntegrationHelpers